//---------------------------------------------------------------------------

#ifndef BCMortH
#define BCMortH
//---------------------------------------------------------------------------
#include "MortalityBase.h"
/**
* BC Mortality - Version 1.0
*
* This evaluates mortality according to the BC mortality equation.
*
* This class's namestring is "bcmortshell". The parameter file call string is
* "bcmortality".
*
* NOTE from old code: mortality function in Kobe&Coates(1997) uses annual mm
* growth new function is not correct if m1 != 1.0  (Confirm this statement)
*
* Copyright 2003 Charles D. Canham.
* @author Lora E. Murphy
*
* <br>Edit history:
* <br>-----------------
* <br>April 28, 2004 - Submitted as beta (LEM)
* <br>February 8, 2008 - Changed mortality flags from simple booleans to reason
* codes (LEM)
*/
class clBCMort : virtual public clMortalityBase {
//note: need the virtual keyword to avoid base class ambiguity.

  public:

  /**
  * Constructor.  Sets the namestring.
  */
  clBCMort(clSimManager *p_oSimManager);

  /**
  * Destructor.
  */
  ~clBCMort();

  /**
  * Reads in values from the parameter file and makes sure all data needed is
  * collected.
  *
  * @param p_oDoc Parsed DOM tree of parameter file.
  */
  void DoShellSetup(xercesc::DOMDocument *p_oDoc);

  /**
  * Calculates mortality according to the BC mortality equation.
  *
  * @param fDbh DBH of tree being evaluated - for seedlings will be 0
  * @param p_oTree Tree being evaluated
  * @param iSpecies Species of the tree being evaluated
  * @return natural if the tree is to die, notdead if it lives.
  */
  whyDead DoMort(clTree *p_oTree, const float &fDbh, const short int &iSpecies);

  protected:

  short int **mp_iGrowthCodes; /**<data member codes for "Growth" member - species by type*/

  float *mp_fMortAtZeroGrowth; /**<Mortality at zero growth - old code m1*/
  float *mp_fLightDepMort;     /**<Light dependent mortality - old code m2*/
  float m_fNumberYearsPerTimestep; /**<Number of years per timestep*/

  /**
  * Queries for the return codes of the "Growth" float data member of a tree.
  * This data member should have been registered by clGrowthBase child classes.
  * Return codes are captured in the mp_iGrowthCodes array.
  * @throws modelErr if there is no code for any species/type combo which uses
  * this behavior.
  */
  void GetGrowthVariableCodes();
};
//---------------------------------------------------------------------------
#endif
