//---------------------------------------------------------------------------

#ifndef StochasticMortH
#define StochasticMortH
//---------------------------------------------------------------------------
#include "MortalityBase.h"
/**
* Stochastic Mortality - Version 1.0
*
* This evaluates stochastic mortality, either adult or juvenile.  The one
* that is done depends on which behavior name string is put in the parameter
* file - either "adultstochasticmort" or "juvstochasticmort".  This controls
* which set of parameters is read in from the parameter file.  The
* self-thinning is calculated the same way either way.  There may be more than
* one object of this class running around.
*
* This class's namestring is "stochasticmortshell".
*
* Copyright 2003 Charles D. Canham.
* @author Lora E. Murphy
*
* <br>Edit history:
* <br>-----------------
* <br>April 28, 2004 - Submitted as beta (LEM)
* <br>February 8, 2008 - Changed mortality flags from simple booleans to reason
* codes (LEM)
*/
class clStochasticMort : virtual public clMortalityBase {
//note: need the virtual keyword to avoid base class ambiguity.

  public:

  /**
  * Constructor.
  *
  * @param p_oSimManager Sim Manager object.
  */
  clStochasticMort(clSimManager *p_oSimManager);

  /**
  * Destructor.
  */
  ~clStochasticMort();

  /**
  * Reads in values from the parameter file.
  *
  * @param p_oDoc DOM tree of parsed input file.
  */
  void DoShellSetup(xercesc::DOMDocument *p_oDoc);

  /**
  * Calculates mortality stochastically.
  *
  * @param fDbh DBH of tree being evaluated - for seedlings will be 0
  * @param p_oTree Tree being evaluated
  * @param iSpecies Species of the tree being evaluated
  * @return natural if the tree is to die, notdead if it lives.
  */
  whyDead DoMort(clTree *p_oTree, const float &fDbh, const short int &iSpecies);

  /**
  * Captures the behavior name passed from the parameter file.  This is useful
  * since this class can produce a few different kinds of behaviors.
  *
  * @param cNameString Behavior name from parameter file.
  */
  void SetNameData(char *cNameString);

  protected:

  /**Random mortality rate per species.  This is read as an annual value and
  * compounded to the number of years per timestep during setup.*/
  float *mp_fRandomMort;

  /**If true - adult stochastic - if false, juvenile.*/
  bool m_bIsAdult;

};
//---------------------------------------------------------------------------
#endif
